@@ -154,6 +154,16 @@ bool IncrementalSearchBar::eventFilter(QObject* watched , QEvent* aEvent)
                 emit closeClicked();
                 return true;
             }
+
+            if (keyEvent->key() == Qt::Key_Return && !keyEvent->modifiers()) {
+                emit searchReturnPressed(_searchEdit->text());
+                return true;
+            }
+
+            if ((keyEvent->key() == Qt::Key_Return) && (keyEvent->modifiers() == Qt::ShiftModifier)) {
+                emit searchShiftPlusReturnPressed();
+                return true;
+            }
         }
     }
 
@@ -180,8 +190,15 @@ void IncrementalSearchBar::setFoundMatch(bool match)
                                   .arg(backgroundBrush.brush(_searchEdit).color().name());
 
         _searchEdit->setStyleSheet(matchStyleSheet);
+    } else if (_searchEdit->text().isEmpty()) {
+        clearLineEdit();
     } else {
-        _searchEdit->setStyleSheet(QString());
+        KStatefulBrush backgroundBrush(KColorScheme::View, KColorScheme::PositiveBackground);
+
+        QString matchStyleSheet = QString("QLineEdit{ background-color:%1 }")
+                                  .arg(backgroundBrush.brush(_searchEdit).color().name());
+
+        _searchEdit->setStyleSheet(matchStyleSheet);
     }
 }
 
