@@ -17,9 +17,11 @@
     02110-1301  USA.
 */
 
+// Config
+#include <config-konsole.h>
+
 // Own
 #include "ProcessInfo.h"
-#include <config-konsole.h>
 
 // Unix
 #include <sys/socket.h>
@@ -27,6 +29,7 @@
 #include <arpa/inet.h>
 #include <unistd.h>
 #include <pwd.h>
+#include <sys/param.h>
 
 // Qt
 #include <QtCore/QDir>
@@ -555,21 +558,20 @@ private:
     }
 
     virtual bool readCurrentDir(int aPid) {
-        QFileInfo info(QString("/proc/%1/cwd").arg(aPid));
-
-        const bool readable = info.isReadable();
-
-        if (readable && info.isSymLink()) {
-            setCurrentDir(info.symLinkTarget());
-            return true;
-        } else {
-            if (!readable)
-                setError(PermissionsError);
-            else
-                setError(UnknownError);
-
+        char path_buffer[MAXPATHLEN + 1];
+        path_buffer[MAXPATHLEN] = 0;
+        QByteArray procCwd = QFile::encodeName(QString("/proc/%1/cwd").arg(aPid));
+        const int length = readlink(procCwd.constData(), path_buffer, MAXPATHLEN);
+        if (length == -1) {
+            setError(UnknownError);
             return false;
         }
+
+        path_buffer[length] = '\0';
+        QString path = QFile::decodeName(path_buffer);
+
+        setCurrentDir(path);
+        return true;
     }
 
     virtual bool readEnvironment(int aPid) {
@@ -871,6 +873,8 @@ private:
         return false;
     }
 
+    // FIXME: This will have the same issues as BKO 251351; the Linux
+    // version uses readlink.
     virtual bool readCurrentDir(int aPid) {
         QFileInfo info(QString("/proc/%1/path/cwd").arg(aPid));
         const bool readable = info.isReadable();
