@@ -380,6 +380,11 @@ QString Session::checkProgram(const QString& program)
     if (exec.isEmpty())
         return QString();
 
+    QFileInfo info(exec);
+    if (info.isAbsolute() && info.exists() && info.isExecutable()) {
+        return exec;
+    }
+
     exec = KRun::binaryName(exec, false);
     exec = KShell::tildeExpand(exec);
     QString pexec = KStandardDirs::findExe(exec);
@@ -466,8 +471,6 @@ void Session::run()
         _shellProcess->setInitialWorkingDirectory(_initialWorkingDir);
     } else {
         _shellProcess->setInitialWorkingDirectory(QDir::currentPath());
-        // for all following invocation, use $HOME as fallback
-        QDir::setCurrent(QDir::homePath());
     }
 
     _shellProcess->setFlowControlEnabled(_flowControlEnabled);
